#####################################################
#        Epiphytic diatom community structure       #
#       and richness determined by algal host and   #
#         sampling location in the South            #
#           Shetland Islands (Antarctica)           #
#                                                   #
#   A. Burfeid-Castellanos, R. Martín, M. Kloster,  #
#    C. Angulo-Preckler, C. Avila & B. Beszteri     #
#                                                   #
#                      Ecology                      #
#                                                   #
#####################################################

#DC2 campaign 2016-2017
#BB1 campaign 2017-2018
#BB2 campaign 2018-2019

#packages
library(vegan)
library(vegetarian)
library(microbiome)
library(corrplot)
library(dplyr)
require(ggplot2)

#set directory
setwd("C:/Users/Andrea/Desktop/Epiphytic diatom community structure and richness determined by algal host and sampling location in the South Shetland Islands Antarctica")
#setwd("C:/Users/Freddie/Desktop/Rafa/Biigle results/Abundances")
setwd("set your directory here")

#Open total abundance data
total<-read.table("Taxa Matrix and Environmental parameters.txt", header = T, row.names = 1, sep = "\t")

Ph<-subset(total, "Phylum.basibiont"== "Phaeo")
Rh<-subset(total, "Phylum.basibiont"== "Rhodo")
Ch<-subset(total, "Phylum.basibiont"== "Chloro")

total<-rbind(Ph,Rh,Ch)

#subdivision into inventory (data) and environmental (env)
env<-total[,132:139]
data<-total[,1:131]

#Open percentage data
#datp <-read.table("Epiphytes_per.txt", header = T, row.names = 1, sep = "\t")
#attach(data)
sp<-total[,1:129]

#Shannon-entropy
basi$diversity<-diversity(sp, index = "shannon", MARGIN = 1, base = exp(1))

#Richness
basi$rich<-specnumber(sp)

#simpson index
diversity(data[,-1], index = "simpson", MARGIN = 1, base = exp(1))

R<-specnumber(data)
Shan <- diversity(data[,-1], index = "shannon")
Simp <- diversity(data[,-1], index = "simpson")
Inv <- diversity(data[,-1], index = "inv")
Ev<-evenness(data[,-1])
source("Evenness index.R")


#Shan <- diversity(tot, index = "shannon")
#Simp <- diversity(tot, index = "simpson")
#Inv <- diversity(tot, index = "inv")
#R<-specnumber(tot)


#Unbiased simpson (Hulbert 1971, eq. 5) with rarefy
unbias.simp<-rarefy(data[,-1], 2) - 1
unbias.simp<-rarefy(tot, 2) - 1

#Fisher alpha
alpha<-fisher.alpha(tot)

#plot all
pairs(cbind(R,Shan, Simp, Inv, unbias.simp, alpha), pch="+", col="blue")
write.table(cbind(R,Shan, Simp, Inv, unbias.simp, alpha), "Entropies.txt", sep = "\t", dec = ".")

pairs(cbind(R,Shan, Simp, Inv), pch="+", col="blue")
write.table(cbind(R,Shan, Simp, Inv), "Mantel Entropies.txt", sep = "\t", dec = ".")
write.table(sim, "SIMPER analysis.txt", sep = "\t", dec = ".")
out <- capture.output(summary(sim))
options("max.print" = 1000000000)
cat("My title", out, file="SIMPER analysis.txt", sep="\t", append=TRUE)
names(env)

res1 <- cor.mtest(data, conf.level = .95)
res2 <- cor.mtest(data, conf.level = .99)
M<-cor(data)

## specialized the insignificant value according to the significant level
corrplot(M, p.mat = res1$p, sig.level = .2)
corrplot(M, p.mat = res1$p, method = "color", type = "upper",
         sig.level = c(.001, .01, .05), pch.cex = .9,
         insig = "label_sig", pch.col = "white", order = "AOE")

