#####################################################
#        Epiphytic diatom community structure       #
#       and richness determined by algal host and   #
#         sampling location in the South            #
#           Shetland Islands (Antarctica)           #
#                                                   #
#   A. Burfeid-Castellanos, R. Martín, M. Kloster,  #
#    C. Angulo-Preckler, C. Avila & B. Beszteri     #
#                                                   #
#     IndVal & Depth distribution of epiphytes      #
#####################################################

#DC2 campaign 2016-2017
#BB1 campaign 2017-2018
#BB2 campaign 2018-2019

##packages
#IndVal
library (labdsv)

#Paleo Depth distribution
library(vegan)
library(vegetarian)
library(tidyverse)
library(gridExtra)
library(ggplot2)
library(analogue)
library(tidypaleo)
theme_set(theme_paleo())
library(grid)
library(gtable)
library(viridis)

#set directory
#setwd("C:/Users/Andrea/sciebo/Antarctica/Biigle results/Abundances")
setwd("set your directory here")

#Open total abundance databases
#IndVal
samples<-read.table("Phylum Indval.txt", header = T, sep = "\t")
samples1<-read.table("RP Phylum Indval.txt", header = T, sep = "\t")
samples2<-read.table("Basibiont Indval.txt", header = T, sep = "\t")
samples3<-read.table("Campaign Indval.txt", header = T, sep = "\t")
samples4<-read.table("Loc Indval.txt", header = T, sep = "\t")
samples5<-read.table("Total_morphbasi.txt", header = T, sep = "\t")
samples6<-read.table("Total_branchbasi.txt", header = T, sep = "\t")
samples7<-read.table("Total_annuality.txt", header = T, sep = "\t")
samples8<-read.table("Predominant diatoms.txt", header = T, sep = "\t", dec = ".")
samples9<-read.table("Total abundance2 morpho indval.txt", header = T, sep = "\t")


#Paleo Depth distribution
data<-read.table("Total_Iris4_most abundant taxa_rp.txt", header = T, sep = "\t")

##IndVal
#transpose database
samples<-t(samples)
samples
names(samples)
sp<-samples1[,1:126]
sp<-samples5[,1:130]#morphbasi
sp<-samples9[,1:121]

sp<-samples[,1:129]
sp2<-samples[,1:14]
new$MY_NEW_COLUMN <-as.numeric(as.character(new[,2])) * 5


# Calculate Indicator Values for species:
iva <- indval(sp[,-1], sp[,1]) # Note that we removed the first column of the file on the first argument, because the types of sites are put on the second one.
iva # Open the file to see the information generated by the function
gr <- iva$maxcls[iva$pval<=0.05]
iv <- iva$indcls[iva$pval<=0.05]
pv <- iva$pval[iva$pval<=0.05]
fr <- apply(samples[,-1]>0, 2, sum)[iva$pval<=0.05]
indvalsummary <- data.frame(group=gr, indval=iv, pvalue=pv, freq=fr)
indvalsummary <- indvalsummary[order(indvalsummary$group, -indvalsummary$indval),]
summary<-summary(iva,type="long")
# Let us see the results
indvalsummary
summary
clust <- cut(samples$Morph.basi,3,labels=FALSE)
summary(indval(sp[,1],clust))


# Calculate Indicator Values for species:
iva <- indval(sp[,-1], sp[,1]) # Note that we removed the first column of the file on the first argument, because the types of sites are put on the second one.
iva # Open the file to see the information generated by the function
gr <- iva$maxcls[iva$pval<=0.05]
iv <- iva$indcls[iva$pval<=0.05]
pv <- iva$pval[iva$pval<=0.05]
fr <- apply(samples[,-1]>0, 2, sum)[iva$pval<=0.05]
indvalsummary <- data.frame(group=gr, indval=iv, pvalue=pv, freq=fr)
indvalsummary <- indvalsummary[order(indvalsummary$group, -indvalsummary$indval),]
summary<-summary(iva,type="long")
# Let us see the results
indvalsummary
summary



##Depth distributions (paleolimnology style)

#Open total abundance data of rhodo and phaeophytes

#Depth distribution of diatoms from Rhodo and Phaeophytes in each island (gray background)
halifax_aplot <- ggplot(data, aes(x = Percentage, y = Depth, fill = Island)) +
  geom_colh(width = 0.5, position = "dodgev") +
  scale_fill_manual(values=c("blue", "gold"))+
  scale_y_reverse() +
  facet_abundanceh(vars(Species)) +
  labs(x = "Relative abundance (%)", y = "Depth (m)", fill = "Island")

halifax_aplot

png(
  "my_species_basi_plot.png", 
  width = 6.5, 
  height = 4, 
  res = 300,
  units = "in"
)
grid::grid.draw(halifax_plot)
dev.off()

pdf(
  "my_species_basi_plot.pdf", 
  width = 6.5, 
  height = 4
)
grid::grid.draw(halifax_plot)
dev.off()

#Depth distribution of diatoms from Rhodo and Phaeophytes on each host class (gray background)
halifax_bplot <- ggplot(data, aes(x = Percentage, y = Depth, fill = Phylum)) +
  geom_colh(width = 0.5, position = "dodgev") +
  scale_fill_manual(values=c("chocolate4", "red"))+
  scale_y_reverse() +
  facet_abundanceh(vars(Species)) +
  labs(x = "Relative abundance (%)", y = "Depth (m)", fill = "Phylum")

halifax_bplot

png(
  "my_species_hali_basi_plot.png", 
  width = 6.5, 
  height = 4, 
  res = 300,
  units = "in"
)
grid::grid.draw(halifax_bplot)
dev.off()

#Depth distribution of diatoms from Rhodo and Phaeophytes in each campaign (gray background)
halifax_cplot <- ggplot(data, aes(x = Percentage, y = Depth, fill = Campaign)) +
  geom_colh(width = 0.5, position = "dodgev") +
  scale_fill_manual(values=c("cyan", "palegreen", "orchid4"))+
  scale_y_reverse() +
  facet_abundanceh(vars(Species)) +
  labs(x = "Relative abundance (%)", y = "Depth (m)", fill = "Campaign")

halifax_cplot

png(
  "my_species_hali_camp_plot.png", 
  width = 6.5, 
  height = 4, 
  res = 300,
  units = "in"
)
grid::grid.draw(halifax_cplot)
dev.off()

pdf(
  "my_species_hali_camp_plot.pdf", 
  width = 6.5, 
  height = 4
)
grid::grid.draw(halifax_cplot)
dev.off()



g2 <- halifax_aplot
g3 <- halifax_bplot
g4 <- halifax_cplot
g <- rbind(g2, g3, g4, size = "first")
g$widths <- unit.pmax(g2$widths, g3$widths, g4$Widths)
grid.newpage()
grid.draw(g)

grid.arrange(g2, g3, g4, ncol = 1)




png(
  "Comparison halifax.png", 
  width = 6.5, 
  height = 12, 
  res = 300,
  units = "in"
)
grid::grid.draw(h)
dev.off()

pdf(
  "Comparison halifax.pdf", 
  width = 6.5, 
  height = 12,
)
grid::grid.draw(h)
dev.off()





