#####################################################
#        Epiphytic diatom community structure       #
#       and richness determined by algal host and   #
#         sampling location in the South            #
#           Shetland Islands (Antarctica)           #
#                                                   #
#   A. Burfeid-Castellanos, R. Martín, M. Kloster,  #
#    C. Angulo-Preckler, C. Avila & B. Beszteri     #
#                                                   #
#                   Mantle test                     #
#                                                   #
#####################################################

#DC2 campaign 2016-2017
#BB1 campaign 2017-2018
#BB2 campaign 2018-2019

#set directory
#setwd("C:/Users/Andrea/sciebo/Antarctica/Biigle results/Abundances")
setwd("set your directory here")

#packages
library(ade4)
library(vegan)
#install.packages("geosphere")
library(geosphere)
library(ecodist)

#Open total databases
samples<-read.table("Tmantel pa.txt", header = T, row.names=1,sep = "\t")
#samples<-read.table("Total_abun_modi.txt", header = T, row.names = 1, sep = "\t")
#Loc<-read.table("UTM Muestras.txt", header = T, row.names = 1, sep = "\t")
#Loc<-read.table("UTM Muestras.txt", header = T, row.names = 1, sep = "\t")
#samples<-read.table("Mantle.txt", header = T, row.names=1,sep = "\t")
#samples<-read.table("Mantleish.txt", header = T, row.names=1,sep = "\t")
#samples<-read.table("Total.txt", header = T, row.names = 1, sep = "\t")

#### DATA PREPARATION ####
sp<-samples[,1:166]
loc<-samples[,167:168]

#subset for each island, Dec = Deception Island, Liv = Livingston Island
Dec<-subset(samples, Loc == "D")
Liv<-subset(samples, Loc == "L")
#LocDec<-subset(Loc, Loc == "D")
#LocLiv<-subset(Loc, Loc == "L")

#Standarization for Deception Island
abund<-samples[,1:129]
sqabun <-sqrt(abund)
abundD<-Dec[,1:129]
abundD[abundD>0]<-1

#Standarization for Livingston Island
abundL<-Liv[,1:129]
abundL[abundL>0]<-1

distm (c(lon1, lat1), c(lon2, lat2), fun = distHaversine)

#Make Prensence / Absence Matrixes
samples[samples>0]<-1
abund[abund>0]<-1

#### MANTEL TEST WHOLE DATASET ####
##Preparation of the variables##
#environmental vector
temp = df$Temperature

#longitude and latitude 
geo = data.frame(samples$Long, samples$Lat)

#abundance data frame - bray curtis dissimilarity
dist.abund = vegdist(sqabun, method = "bray")

#environmental vector - euclidean distance
dist.temp2 = dist(samples$Phylum.basibiont, method = "euclidean")

#environmental vector - euclidean distance
dist.depth = dist(samples$Depth, method = "euclidean")

#geographic data frame - haversine distance 
d.geo = distm(geo, fun = distHaversine)
dist.geo = as.dist(d.geo)

##Two-way comparison##
#abundance vs environmental 
abund_temp = mantel(dist.abund, dist.temp, method = "spearman", permutations = 9999, na.rm = TRUE)
abund_temp

abund_temp2 = mantel(dist.abund, dist.temp2, method = "spearman", permutations = 9999, na.rm = TRUE)
abund_temp2
#abundance vs environmental Depth
abund_depth = mantel(dist.abund, dist.depth, method = "spearman", permutations = 9999, na.rm = TRUE)
abund_depth

#abundance vs geographic 
abund_geo  = mantel(dist.abund, dist.geo, method = "spearman", permutations = 9999, na.rm = TRUE)
abund_geo

#abundance vs temperature test
abund_temp


plot(r1 <- mantel.rtest(dist.geo,dist.abund), main = "Mantel's test", replicate=9999)
r1
#create environmental data frame 
#make subset
names(samples)
env = c(samples$Depth, samples$Temp)

#scale data 
scale.env = scale(env, center = TRUE, scale = TRUE)

#create distance matrix of scaled data
dist.env = dist(scale.env, method = "euclidean")

#run mantel test 
abund_env = mantel(dist.abund, dist.env, method = "spearman", permutations = 9999, na.rm = TRUE)
abund_env
#abundance vs geography test
abund_geo

#### MANTEL TEST Deception ####
##Preparation of the variables##
#longitude and latitude 
geo = data.frame(LocDec$Long, LocDec$Lat)

#abundance data frame - bray curtis dissimilarity
dist.abund = vegdist(abundD, method = "bray")

#environmental vector - euclidean distance
dist.temp = dist(Dec$Temp, method = "euclidean")

#environmental vector - euclidean distance
dist.depth = dist(Dec$Depth, method = "euclidean")

#geographic data frame - haversine distance 
d.geo = distm(geo, fun = distHaversine)
dist.geo = as.dist(d.geo)

##Two-way comparison##
#abundance vs environmental 
abund_temp = mantel(dist.abund, dist.temp, method = "spearman", permutations = 9999, na.rm = TRUE)
abund_temp

#abundance vs environmental Depth
abund_depth = mantel(dist.abund, dist.depth, method = "spearman", permutations = 9999, na.rm = TRUE)
abund_depth

#abundance vs geographic 
abund_geo  = mantel(dist.abund, dist.geo, method = "spearman", permutations = 9999, na.rm = TRUE)
abund_geo

#abundance vs temperature test
abund_temp

# Abundance of this grass is related to forest cover but not location
MRM(dist.abund ~ dist.geo + dist.depth,  nperm=10000)



plot(r1 <- mantel.rtest(dist.geo,dist.abund), main = "Mantel's test", replicate=9999)
r1
#create environmental data frame 
#make subset
names(samples)
env = c(samples$Depth, samples$Temp)

#scale data 
scale.env = scale(env, center = TRUE, scale = TRUE)

#create distance matrix of scaled data
dist.env = dist(scale.env, method = "euclidean")

#run mantel test 
abund_env = mantel(dist.abund, dist.env, method = "spearman", permutations = 9999, na.rm = TRUE)
abund_env

#abundance vs geography test
abund_geo

#### MANTEL TEST WHOLE DATASET ####
##Preparation of the variables##

#longitude and latitude 
geo = data.frame(LocLiv$Long, LocLiv$Lat)

#abundance data frame - bray curtis dissimilarity
dist.abund = vegdist(abundL, method = "bray")

#environmental vector - euclidean distance
dist.temp = dist(Liv$Temp, method = "euclidean")

#environmental vector - euclidean distance
dist.depth = dist(Liv$Depth, method = "euclidean")

#geographic data frame - haversine distance 
d.geo = distm(geo, fun = distHaversine)
dist.geo = as.dist(d.geo)

##Two-way comparison##
#abundance vs environmental 
abund_temp = mantel(dist.abund, dist.temp, method = "spearman", permutations = 9999, na.rm = TRUE)
abund_temp

#abundance vs environmental Depth
abund_depth = mantel(dist.abund, dist.depth, method = "spearman", permutations = 9999, na.rm = TRUE)
abund_depth

#abundance vs geographic 
abund_geo  = mantel(dist.abund, dist.geo, method = "spearman", permutations = 9999, na.rm = TRUE)
abund_geo

#depth vs geographic
abund_geo  = mantel(dist.depth, dist.geo, method = "spearman", permutations = 9999, na.rm = TRUE)
abund_geo

# Abundance of this grass is related to forest cover but not location
MRM(dist.abund ~ dist.geo + dist.depth,  nperm=10000)

plot(r1 <- mantel.rtest(dist.geo,dist.abund), main = "Mantel's test", replicate=9999)
r1

#create environmental data frame 
#make subset
names(samples)
env = c(samples$Depth)

#scale data 
scale.env = scale(env, center = TRUE, scale = TRUE)

#create distance matrix of scaled data
dist.env = dist(scale.env, method = "euclidean")

#run mantel test 
abund_env = mantel(dist.abund, dist.env, method = "spearman", permutations = 9999, na.rm = TRUE)
abund_env
#abundance vs geography test
abund_geo




#regression
#dist.abun
#dist.env
#dist.geo
dist.abund
scatter.smooth(x=dist.abund, y=dist.env, main="abundance ~ loc")  # scatterplot
lm



data(graze)

View(graze)

# Abundance of this grass is related to forest cover but not location
MRM(dist.abund ~ dist.geo + dist.env,  nperm=10000)

