#####################################################
#        Epiphytic diatom community structure       #
#       and richness determined by algal host and   #
#         sampling location in the South            #
#           Shetland Islands (Antarctica)           #
#                                                   #
#   A. Burfeid-Castellanos, R. Martín, M. Kloster,  #
#    C. Angulo-Preckler, C. Avila & B. Beszteri     #
#                                                   #
#             PERMANOVA and SIMPER                  #
#                                                   #
#####################################################

#libraries
library(vegan)
library(phyloseq)

#Permanova

#setwd("C:/Users/Andrea/sciebo/Antarctica/Biigle results/Abundances")
setwd("set your directory here")

#Open total databases
tot<-read.table("total orga.txt", header = T, sep = "\t")
macro<-read.table("SIMPER.txt", header = T, sep = "\t")
bib<-read.table("tMantle redu2.txt", header = T, sep = "\t")
spp<-tot[,1:131]
spdf<-spp


# species matrix
#subset for each island, Dec = Deception Island, Liv = Livingston Island
Dec <-spp[1:15,]
Liv<-spp[16:38,]

#environmental database
env<-tot[,135:137]

#SIMPER Analysis --> Cocconeis fasciolata imperatrix, Gomphonempsis ligowskii
sim<-with(env, simper(spp, tot$Loc, permutations = 9999))
#see the results
summary(sim)


names(macro)
env<-macro[,2:19]
macro<-macro$LOC
sim<-simper(env, macro, permutations = 9999)
summary(sim, ordered = TRUE, digits = 3)
lapply(sim, FUN=function(x){x$overall})

names(bib)
bib<-data.frame(bib)
env[env>0]<-1
env<-bib[,2:129]
loc<-bib$n.taxa.basibionts
sim<-simper(env, loc, permutations = 9999)
summary(sim, ordered = TRUE, digits = 3)
lapply(sim, FUN=function(x){x$overall})
simpcom<-simper(comm = data, group = env$Phylum.basibiont, permutations = 9999)
simpcom
summary(simpcom, ordered = TRUE, digits = 3)
lapply(simpcom, FUN=function(x){x$overall})
lapply(sim, FUN=function(x){x$overall})
sim2 <- with(env$Basibiont, simper(data, env$Depth))
summary(sim)



#PERMANOVA
adonis2(spp~tot$Loc*Depth, data = env, permutations = 9999)
#adonis2(spp~tot$Loc, data = tot, permutations = 9999)
#LOC ***, Depth **

#Identity for Cocconeis fasciolata
p.phyla <- ggplot(tot, aes(x = image_filename, y = spp$Cocconeis.fasciolata..imperatrix., fill = Loc)) + 
  geom_bar(stat = "identity") +
  # Remove x axis title
  theme(axis.title.x = element_blank()) + 
  #
  guides(fill = guide_legend(reverse = TRUE, keywidth = 1, keyheight = 1)) +
  ylab("Relative Abundance (Phyla > 2%) \n") +
  ggtitle("Phylum Composition of GlobalPatterns Communities by Sample") 

print(p.phyla)

#Identity for Gomphonemopsis ligowskii (G. littoralis)
p.phyla <- ggplot(tot, aes(x = image_filename, y = spp$Gomphonemopsis.littoralis, fill = Loc)) + 
  geom_bar(stat = "identity") +
  # Remove x axis title
  theme(axis.title.x = element_blank()) + 
  #
  guides(fill = guide_legend(reverse = TRUE, keywidth = 1, keyheight = 1)) +
  ylab("Relative Abundance (Phyla > 2%) \n") +
  ggtitle("Phylum Composition of GlobalPatterns Communities by Sample") 

print(p.phyla)


###
# PERMANOVA #####
###
set.seed(1)

# Calculate bray curtis distance matrix
spp_bray <- phyloseq::distance(spp, method = "bray")
spp_bray<-vegdist(spp, method = "bray")

# make a data frame from the sample_data
sampledf <- data.frame(sample_data(spp))

# Adonis test
adonis(spp_bray ~ tot$Loc, data = sampledf)
adonis(spp_bray ~ tot$Depth, data = sampledf)
adonis(spp_bray ~ tot$Loc + tot$Depth, data = sampledf)
