#####################################################
#        Epiphytic diatom community structure       #
#       and richness determined by algal host and   #
#         sampling location in the South            #
#           Shetland Islands (Antarctica)           #
#                                                   #
#   A. Burfeid-Castellanos, R. Martín, M. Kloster,  #
#    C. Angulo-Preckler, C. Avila & B. Beszteri     #
#                                                   #
#                   Whole dataset                   #
#####################################################

#DC2 campaign 2016-2017
#BB1 campaign 2017-2018
#BB2 campaign 2018-2019

## install iNEXT package from CRAN
#install.packages("iNEXT")
## install the latest version from github
#install.packages('devtools')
#install_github('JohnsonHsieh/iNEXT')
#install.packages("ggord")
#install_github('fawda123/ggord')
#install.packages("coin")
#install.packages(gg_ordiplots)
#devtools::install_github("jfq3/ggordiplots")

#packages
#install.packages("tesseract")
library (tesseract)
library(MASS)
library(vegan)
library(vegetarian)
library(ggplot2)
library(corrplot)
library(dplyr)
library(plyr)
library(devtools)
library(iNEXT)
library(ggord)
library(coin)
library(ggordiplots)




options(scipen=999)

#set directory
setwd("set your directory here")
#setwd("C:/Users/Andrea/sciebo/Antarctica/Biigle results/Abundances")

#Open total abundance databases
totc<-read.table("Taxa Matrix and Environmental parameters.txt", header = T, row.names = 1,sep = "\t")
#tot<-read.table("Total abundance.txt", header = T, row.names = 1,sep = "\t", dec = ".")
#redu<-read.table("Total redu.txt", header = T, row.names = 1, dec = ".", sep = "\t")
#basi<-read.table("Total basi.txt", header = T, row.names = 1, sep = "\t", dec = ".")
#loc<-read.table("Total loc.txt", header = T, row.names = 1, sep = "\t", dec = ".")
#samples<-read.table("tMantle2.txt", header = T, row.names=1,sep = "\t")
#diris <- read.table("Total_Iris3_most abundant taxa.txt", header = T,  dec = ".", sep = "\t")
#pred<-read.table("Predominant diatoms.txt", header = T, row.names = 1, sep = "\t", dec = ".")


#Transformation of the database
View(sp)
names(totc)

#Abundance database
sp<-tot[,1:129]
env<-totc[,132:148]
names(tot)
sdata<-sqrt(sp)
ldata<-log(sp+1)

norm(sdata)
hist(ldata)

#Total database
sp<-totc[,1:129]
env<-totc[,132:139]
names(tot)
scdata<-sqrt(sp)
lcdata<-log(sp+1)

#non metric dimensional scaling, hosts and location
vare.dis<-vegdist(sdata)
vare.mds0 <- isoMDS(vare.dis)
stressplot(vare.mds0, vare.dis)
vare.mds<-metaMDS(sdata, distance = "bray")
vare.mds
plot(vare.mds, type="n")
pchs<- c(15:20)
col.gr <- c("dodgerblue4","darkorange4","gold", "orangered","deepskyblue4","blue","red","cornflowerblue", "magenta", "mediumorchid1","darkslateblue","coral1","forestgreen", "firebrick3", "indianred", "deeppink", "tomato2", "coral3")

orditorp(vare.mds, display = "species", col = "dark grey", air = 0.01)
points(vare.mds, display = "sites", pch = pchs[env$Loc], col = col.gr[env$Basibiont])
legend("topright", legend=levels(env$Loc), bty = "n", col= c("black"), pch = pchs)
legend("bottomright", legend = levels(env$Basibiont), bty = "n", col = col.gr, pch=c(20),)


vare.dis<-vegdist(sdata)
vare.mds0 <- isoMDS(vare.dis)
stressplot(vare.mds0, vare.dis)
vare.mds<-metaMDS(sdata, distance = "bray")
vare.mds

pchs<- c(0:18)
col.gr <- c("blue", "gold")
plot(vare.mds, type="n", xlim=c(-1.75,2),ylim=c(-1.0,2.0))
#orditorp(vare.mds, display = "species", col = "dark grey", air = 0.01)
points(vare.mds, display = "sites", pch = pchs[env$Basibiont], col = col.gr[env$Loc])
legend("bottomright", legend=levels(env$Basibiont), bty = "n", col= c("black"), pch = pchs)
legend("topright", legend = levels(env$Loc), bty = "n", col = col.gr, pch=c(19),)


#ANOSIM of squareroot data
anosim<-anosim(sdata, env$Loc, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
anosim
summary(anosim)
plot(anosim)

#ANOSIM Location and Antarctica location
anosim<-anosim(sdata, env$Loc*env$Ant, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
anosim
summary(anosim)
plot(anosim)

#ANOSIM Basibiont
basi.ano<-anosim(sdata, env$Basibiont, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
basi.ano
summary(basi.ano)
plot(basi.ano)

#ANOSIM phylum host
phyl.ano<-anosim(sdata, env$Phylum.basibiont, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
phyl.ano
summary(phyl.ano)
plot(phyl.ano)

#ANOSIM depth
depth.ano<-anosim(sdata, env$Depth, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
depth.ano
summary(depth.ano)
plot(depth.ano)

#ANOSIM depth intervals
depth.int.ano<-anosim(sdata, env$Depth.int, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
depth.int.ano
summary(depth.int.ano)
plot(depth.int.ano)

#ANOSIM per expedition
campaign.ano<-anosim(sdata, env$Campaign, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
campaign.ano
summary(campaign.ano)
plot(campaign.ano)

#Morphological changes

#Host morphology
morph.ano<-anosim(sdata, env$Basibiont.talus.morphology, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
morph.ano
summary(morph.ano)
plot(morph.ano)

#Host branchedness
Branch.ano<-anosim(sdata, env$Branchedness, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
Branch.ano
summary(Branch.ano)
plot(Branch.ano)

#Host survival
annu.ano<-anosim(sdata, env$Basibiont.annuality, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
annu.ano
summary(annu.ano)
plot(annu.ano)

#Dissimilarity
# Start writing to an output file

sredu<-sqrt(redu)
sink('Results_redu.txt')

#SIMPER logarithmic data per location
lloc<-simper(ldata, env$Loc, permutations = 9999)

#SIMPER reduced dataset
summary(with(env, simper(sredu, env$Loc, permutations = 9999)))

#SIMPER squareroot diatom data ^ host
summary(with(env, simper(sdata, env$Basibiont, permutations = 9999)))

#SIMPER squareroot diatom data ^ host class
summary(with(env, simper(sdata, env$Phylum.basibiont, permutations = 9999)))

#SIMPER squareroot diatom data ^ expedition
summary(with(env, simper(sdata, env$Campaign, permutations = 9999)))

#SIMPER squareroot diatom data ^ depth
summary(with(env, simper(sdata, env$Depth, permutations = 9999)))

#SIMPER squareroot diatom data ^ depth division
summary(with(env, simper(sdata, env$Depth.div, permutations = 9999)))

#SIMPER squareroot data ^ morphology of the host
summary(with(env, simper(sdata, env$Morph.basi, permutations = 9999)))

#SIMPER squareroot data ^ host branchedness
summary(with(env, simper(sdata, env$Branchedness.basi, permutations = 9999)))

#SIMPER squareroot data ^ survival host
summary(with(env, simper(sdata, env$Annuality, permutations = 9999)))



#Deception subset

Dec<-subset(tot, Loc=="D")
Dsp<-Dec[,1:129]
Denv<-Dec[,132:142]

#Livingston subset
Liv<-subset(tot, Loc=="L")
Lsp<-Liv[,1:129]
names(Liv)
Lenv<-Liv[,132:142]

#Rarefaction curves
rarefy(sp, sample=10, MARGIN=1)
S<-specnumber(sp)
(raremax<-min(rowSums(sp)))
Srare<-rarefy(sp, raremax)
plot(S, Srare, xlab = "Observed # of species", ylab = "Rarefied # of species")
abline(0,1)
rarecurve(sp, step = 20, sample = raremax, col = "blue", cex=0.6)
names(loc)

#Rarefaction curves per host
row.names(basi)
cols <- c("gold"=Bacil, "Green" = Chloro, "Chocolate" = Phaeo, 
          "red" = Rhodo)
Srar<-rarefy(basi, min(rowSums(basi)))
S2<-rarefy(basi, 2)
all(rank(Srar)==rank(S2))
range(diversity(basi,"simp")-S2-1)
taxdis<-taxa2dist(basi, varstep = TRUE)

rarefy(basi, sample=10, MARGIN=1)
S<-specnumber(basi)
(raremax<-min(rowSums(basi)))
Srare<-rarefy(basi, raremax)
plot(S, Srare, xlab = "Observed # of species", ylab = "Rarefied # of species")
abline(0,1)
rarecurve(basi, step = 20, sample = raremax, col = "gold", cex=0.6)



tbasi<-t(basi)
iNEXT(tbasi, q=0, datatype="abundance", size=NULL, endpoint=NULL, knots=40, se=TRUE, conf=0.95, nboot=50)

out <- iNEXT(tbasi, q=c(0, 1, 2), datatype="abundance", endpoint=500)
ggiNEXT(out, type=1, facet.var="none", grey = TRUE)

g<-ggiNEXT(out, type = 2)

g +theme_bw() + scale_colour_manual(values = c("gold","green","chocolate","red"))+
  scale_fill_manual(values = c("gold","green","chocolate","red"))

tr<-hclust(taxdis, "aver")
plot(tr)

#Rarefaction curves per island


tloc<-t(loc)
iNEXT(tloc, q=0, datatype="abundance", size=NULL, endpoint=NULL, knots=40, se=TRUE, conf=0.95, nboot=50)

out <- iNEXT(tloc, q=c(0, 1, 2), datatype="abundance", endpoint=500)
ggiNEXT(out, type=2, facet.var="none")

g<-ggiNEXT(out, type = 2)

g +theme_bw() + scale_colour_manual(values = c("blue","gold"))+
  scale_fill_manual(values = c("blue","gold"))


Srar<-rarefy(loc, min(rowSums(loc)))
S2<-rarefy(loc, 2)
all(rank(Srar)==rank(S2))
range(diversity(loc,"simp")-S2-1)
taxdis<-taxa2dist(loc, varstep = TRUE)

tr<-hclust(taxdis, "aver")
plot(tr)

rarefy(loc, sample=10, MARGIN=1)
S<-specnumber(loc)
(raremax<-min(rowSums(loc)))
Srare<-rarefy(loc, raremax)
plot(S, Srare, xlab = "Observed # of species", ylab = "Rarefied # of species")
abline(0,1)
rarecurve(loc, step = 20, sample = raremax, col = "blue", cex=0.6)

rarefy(Lsp, sample=10, MARGIN=1)
SL<-specnumber(Lsp)
(raremax<-min(rowSums(Lsp)))
SLrare<-rarefy(Lsp, raremax)
plot(SL, SLrare, xlab = "Observed # of species", ylab = "Rarefied # of species")
abline(0,1)
rarecurve(Lsp, step = 20, sample = raremax, col = "blue", cex=0.6)

#Diversity 
H <- diversity(sp)
H

#Evenness
J <- H/log(specnumber(sp))
J

k <- sample(nrow(sp),6)
R<-renyi(sp[k,])
alpha<-fisher.alpha(sp)

k
R
alpha

#ANOSIM LOCS
names(rp)
sp<-rp[,1:129]
env<-rp[,130:137]

sqrtsp<-sqrt(sp)
anosim<-anosim(sqrtsp, env$Loc, permutations = 9999, distance = "bray", strata = NULL, parallel = getOption("mc.cores"))
summary(anosim)

#ANOSIM per island
#Livingston

#Livingston ANOSIM per site
anosim<-anosim(Lsp, Lenv$Loc, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
anosim
summary(anosim)
plot(anosim)

#Livingston ANOSIM per host
basi.ano<-anosim(Lsp, Lenv$Basibiont, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
basi.ano
summary(basi.ano)
plot(basi.ano)

#Livingston ANOSIM per host class
phyl.ano<-anosim(Lsp, Lenv$Phylum.basibiont, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
phyl.ano
summary(phyl.ano)
plot(phyl.ano)

#Livingston ANOSIM per depth
depth.ano<-anosim(Lsp, Lenv$Depth, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
depth.ano
summary(depth.ano)
plot(depth.ano)

#Livingston ANOSIM per depth interval
depth.int.ano<-anosim(Lsp, Lenv$Depth.int, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
depth.int.ano
summary(depth.int.ano)
plot(depth.int.ano)

#Livingston ANOSIM per expedition
campaign.ano<-anosim(Lsp, Lenv$Campaign, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
campaign.ano
summary(campaign.ano)
plot(campaign.ano)

names(env)
#Livingston ANOSIM per host morphology
morph.ano<-anosim(Lsp, Lenv$Basibiont.talus.morphology, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
morph.ano
summary(morph.ano)
plot(morph.ano)

#Livingston ANOSIM per host branchedness
Branch.ano<-anosim(Lsp, Lenv$Branchedness, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
Branch.ano
summary(Branch.ano)
plot(Branch.ano)

#Livingston ANOSIM per host survival
annu.ano<-anosim(Lsp, Lenv$Basibiont.annuality, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
annu.ano
summary(annu.ano)
plot(annu.ano)

#Deception

#Deception ANOSIM per site
anosim<-anosim(Dsp, Denv$Loc, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
anosim
summary(anosim)
plot(anosim)

#Deception ANOSIM per  per host
basi.ano<-anosim(Dsp, Denv$Basibiont, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
basi.ano
summary(basi.ano)
plot(basi.ano)

#Deception ANOSIM per host class
phyl.ano<-anosim(Dsp, Denv$Phylum.basibiont, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
phyl.ano
summary(phyl.ano)
plot(phyl.ano)


depth.ano<-anosim(Dsp, Denv$Depth, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
depth.ano
summary(depth.ano)
plot(depth.ano)


depth.int.ano<-anosim(Dsp, Denv$Depth.int, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
depth.int.ano
summary(depth.int.ano)
plot(depth.int.ano)


depth.div.ano<-anosim(Dsp, Denv$Depth.div, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
depth.div.ano
summary(depth.div.ano)
plot(depth.div.ano)

campaign.ano<-anosim(Dsp, Denv$Campaign, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
campaign.ano
summary(campaign.ano)
plot(campaign.ano)

names(env)
morph.ano<-anosim(Dsp, Denv$Basibiont.talus.morphology, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
morph.ano
summary(morph.ano)
plot(morph.ano)

Branch.ano<-anosim(Dsp, Denv$Branchedness, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
Branch.ano
summary(Branch.ano)
plot(Branch.ano)

annu.ano<-anosim(Dsp, Denv$Basibiont.annuality, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
annu.ano
summary(annu.ano)
plot(annu.ano)

#ANOSIM per Host type
#Rhodophyte

summary(tot)
Rhodo<-subset(tot, Phylum.basibiont == "Rhodo")

Rsp<-Rhodo[,1:129]
Renv<-Rhodo[,132:142]



Ranosim<-anosim(Rsp, Renv$Loc, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
Ranosim
summary(Ranosim)
plot(Ranosim)


Rdepth.ano<-anosim(Rsp, Renv$Depth, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
Rdepth.ano
summary(Rdepth.ano)



plot(Rdepth.ano)


Rdepth.int.ano<-anosim(Rsp, Renv$Depth.int, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
Rdepth.int.ano
summary(Rdepth.int.ano)
plot(Rdepth.int.ano)


Rdepth.div.ano<-anosim(Rsp, Renv$Depth.div, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
Rdepth.div.ano
summary(Rdepth.div.ano)
plot(Rdepth.div.ano)

Rcampaign.ano<-anosim(Rsp, Renv$Campaign, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
Rcampaign.ano
summary(Rcampaign.ano)
plot(Rcampaign.ano)

names(env)
Rmorph.ano<-anosim(Rsp, Renv$Basibiont.talus.morphology, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
Rmorph.ano
summary(Rmorph.ano)
plot(Rmorph.ano)

RBranch.ano<-anosim(Rsp, Renv$Branchedness, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
RBranch.ano
summary(RBranch.ano)
plot(RBranch.ano)

Rannu.ano<-anosim(Rsp, Renv$Basibiont.annuality, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
Rannu.ano
summary(Rannu.ano)
plot(Rannu.ano)



#Phaeophyte

summary(tot)
Phaeo<-subset(tot, Phylum.basibiont == "Phaeo")

Psp<-Phaeo[,1:129]
Penv<-Phaeo[,132:142]



Panosim<-anosim(Psp, Penv$Loc, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
Panosim
summary(Panosim)
plot(Panosim)


Pdepth.ano<-anosim(Psp, Penv$Depth, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
Pdepth.ano
summary(Pdepth.ano)
plot(Pdepth.ano)


Pdepth.int.ano<-anosim(Psp, Penv$Depth.int, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
Pdepth.int.ano
summary(Pdepth.int.ano)
plot(Pdepth.int.ano)


Pdepth.div.ano<-anosim(Psp, Penv$Depth.div, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
Pdepth.div.ano
summary(Pdepth.div.ano)
plot(Pdepth.div.ano)

Pcampaign.ano<-anosim(Psp, Penv$Campaign, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
Pcampaign.ano
summary(Pcampaign.ano)
plot(Pcampaign.ano)

names(env)
Pmorph.ano<-anosim(Psp, Penv$Basibiont.talus.morphology, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
Pmorph.ano
summary(Pmorph.ano)
plot(Pmorph.ano)

PBranch.ano<-anosim(Psp, Penv$Branchedness, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
PBranch.ano
summary(PBranch.ano)
plot(PBranch.ano)

Pannu.ano<-anosim(Psp, Penv$Basibiont.annuality, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
Pannu.ano
summary(Pannu.ano)
plot(Pannu.ano)


#RDA whole dataset

data.rda<-rda(sdata)



scrs<-scores(data.rda, display = c("sites", "species"))
str(scrs, max=1)
xlim<-with(scrs, range(species[,1], sites[,1]))
ylim<-with(scrs, range(species[,2], sites[,2]))

plot.new()
plot.window(xlim = xlim, ylim = ylim, asp = 1)


abline(h = 0, lty = "dotted")
abline(v = 0, lty = "dotted")

colvec <- c("blue", "gold")
with(data.rda, points(scrs$sites, col = colvec[env$Loc],
                      pch = 21, bg = colvec[env$Loc]))
with(data.rda, legend("topright", legend = levels(env$Loc), bty = "n",
                      col = colvec, pch = 21, pt.bg = colvec))
axis(side = 1)
axis(side = 2)
title(xlab = "RDA 1", ylab = "RDA 2")
box()
summary(data.rda)

pchs<- c(0:18)
col.gr <- c("blue", "gold")
plot(data.rda, type="n", xlim=c(-2.5,2),ylim=c(-3.5,2.0),xlab = "RDA 1 (18.2%)", ylab = "RDA 2 (12.08%)")
#orditorp(vare.mds, display = "species", col = "dark grey", air = 0.01)
points(data.rda, display = "sites", pch = pchs[env$Basibiont], col = col.gr[env$Loc])

legend("bottomright", legend=levels(env$Basibiont), bty = "n", col= c("black"), pch = pchs, cex = 0.7)
legend("bottomleft", legend = levels(env$Loc), bty = "n", col = col.gr, pch=c(19))

summary(env)
envi<-env[,4:5]
envfit(data.rda~env$Depth*env$Lat*env$Long, perm = 9999, display = "lc")
summary(data.rda)

#comparison with other data
spm<-samples[,1:168]
envm<-samples[,169:170]
sp[sp>0]<-1
HR.ano<-anosim(spm, env$HR, permutations = 9999, distance = "bray", strata = NULL, parallel=getOption("mc.cores"))
HR.ano
summary(HR.ano)
plot(HR.ano)

# plot the RDA using ggplot (ggord package)

simpleRDA <- rda(ldata ~ Depth + Lat + Long, data=env )
summary(simpleRDA)
coef(simpleRDA)
screeplot(simpleRDA) #bstick not available for constrained ordinations
R2 <- RsquareAdj(simpleRDA)$r.squared
R2 
# adjusted R^2
R2adj <- RsquareAdj(simpleRDA)$adj.r.squared
R2adj 


ggord(simpleRDA, env$Loc) + theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())+ 
  scale_fill_manual(values=c("#000066", "#FFCC33")) # looking at the raw code, this is plotting the 'wa scores', the blue dots are different species 



# Triplot: three different entities in the plot: sites, response variables and explanatory variables (arrowheads are on the explanatory variables)
# Scaling 1
plot(simpleRDA, scaling=1, main="Triplot RDA matrix ~ env - scaling 1 - wa scores")

# arrows for species are missing, so lets add them without heads so they look different than the explanatory variables
spe.sc <- scores(simpleRDA, choices=1:2, scaling=1, display="sp")
arrows(0,0,spe.sc[,1], spe.sc[,2], length=0, lty=1, col='red')


# Scaling 2
plot(simpleRDA, main="Triplot RDA matrix ~ env - scaling 2 - wa scores")
spe2.sc <- scores(simpleRDA, choices=1:2, display="sp") # scores() choices= indicates which axes are to be selected, make sure to specify the scaling if its different than 2 
arrows(0,0,spe2.sc[,1], spe2.sc[,2], length=0, lty=1, col='red')

#montecarlo permutation test

names(diris)

oneway_test(Percentage~Island,data=diris,distribution=approximate(nresample=9999))
oneway_test(Inventory~Island,data=diris,distribution=approximate(nresample=9999))


oneway_test(Percentage~Campaign,data=diris,distribution=approximate(nresample=9999))
oneway_test(Inventory~Campaign,data=diris,distribution=approximate(nresample=9999))

oneway_test(Percentage~Depth.int,data=diris,distribution=approximate(nresample=9999))
oneway_test(Inventory~Depth.int,data=diris,distribution=approximate(nresample=9999))


spearman_test(Percentage ~Depth, data=diris,
              distribution=approximate(nresample = 9999))
norm(sp)
View(sp)
summary(sp)

hist(ldata$Pseudogomphonema.kamtschaticum)

anova<-lm(log(Percentage+1)~Basibiont+Island, diris)
anova<-lm(log(Inventory+1)~Basibiont+Island, diris)
summary(anova)

anova<-lm(log(Percentage+1)~Phylum*Island, diris)
anova<-lm(log(Inventory+1)~Phylum*Island, diris)
summary(anova)

#ggplot2 RDA
p <- ggord(simpleRDA, env$Loc, cols = c('blue', 'gold'))
p
summary(simpleRDA)
# transparent ellipses
p <- ggord(simpleRDA, env$Loc, cols = c('blue', 'gold'), poly = FALSE)
p

summary(env$Phylum.basibiont)

# transparent ellipses
names(env)
p <- ggord(vare.mds, env$Phylum.basibiont, cols = c('gold', 'green','burlywood4', 'red'), poly = FALSE, species = TRUE)
p

View(env)
colors=c("blue","gold")
ordiplot(vare.mds,type="n")
View(vare.mds)
#Plot convex hulls with colors baesd on treatment
for(i in unique(env$Phylum.basibiont)) {
  ordihull(vare.mds$point[grep(i,env$Phylum.basibiont),],draw="polygon",
           groups=env$Phylum.basibiont[env$Phylum.basibiont==i],col=colors[grep(i,env$Phylum.basibiont)],label=F) } 
orditorp(vare.mds,display="species",col="red",air=0.01)
orditorp(vare.mds,display="sites",col=c("blue","gold"),air=0.01,cex=1.25)



# nonmetric multidimensional scaling with the iris dataset
# metaMDS

names(mydata)
env<-mydata[,14:23]
sdata<-sqrt(sp)
ord <- metaMDS(sdata)
env$Phylum.basibiont
ggord(ord, env$Phylum.basibiont, cols = c('gold', 'green','burlywood4', 'red', 'gold'), txt = NULL, vectyp=0)
ggord(ord, env$Phylum.basibiont, cols = c('gold', 'green','burlywood4', 'red', 'gold'))

summary(ord)
grp_in
ord

spbray<-vegdist(sp, method = "bray")
cl <-hclust(spbray, method = "complete")

gg_ordicluster(ord, treatments = env$Phylum.basibiont, cluster = cl, prune = 3,col =cutree(cl, 4), pt.size = 2, draw="polygon",
               groups=env$Phylum.basibiont[env$Phylum.basibiont==i],col=colors[grep(i,env$Phylum.basibiont)],label=F)





ord

#Predominant diatoms

sp<-pred[,1:14]
names(pred)
env2<-pred[,15:23]

sdata2<-sqrt(sp)

ord2 <- metaMDS(sdata2)
env2$Phylum.basibiont
ord2
ggord(ord2, env2$Phylum.basibiont, cols = c('gold', 'green','burlywood4', 'red'))
summary(ord2)
ord

data(dune.env)
View(dune.env)
#MRPP
dune.mrpp <- with(env, mrpp(sp, Loc))
dune.mrpp
